Module model

Module model 

This module provides models that are used in the coinbase module

Modules

shared
This module cointains some auxiliar functions that are used in the openlimits-exchange module
websocket

Structs

Account
This struct represents an account
Book
This struct represents the offer book
BookRecordL1
This struct represents a level 1 book record
BookRecordL2
This struct represents a level 2 book record
BookRecordL3
This struct represents a level 3 book record
CancelAllOrders
This struct represents the cancellation of all orders
CancelOrder
This struct represents the cancellation of an order
Candle
This struct represents the candle
CandleRequestParams
This struct represents the candle request params
DateRange
This struct represents a data range
Fill
This struct represents a fill order
GetFillsReq
This struct represents a request of fill orders
GetOrderRequest
This structs a request of an oder
MarketPair
Order
This struct represents an order
OrderRequest
This struct represents an order request
OrderStop
This struct represents an order stop
Paginator
This struct represents a paginator
Product
This struct represents a product
Ticker
This struct represents a ticker
Trade
This struct represents a trade

Enums

CancelAfter
This enum represents a cancel after order
OrderRequestMarketType
This struct represents a market type request
OrderRequestType
This struct represents a order type request
OrderSide
This enum represents an order side which can be buy-side or sell-side
OrderStatus
This enum represents an order status
OrderStopType
This struct represents the type stop of an order
OrderTimeInForce
This enum represents a time in force order
OrderTimeInForceResponse
This enum represents a response of a time in force
OrderType
This enum represents the order types

Traits

BookLevel